<!DOCTYPE html>
<html lang="en">
<head>

<meta charset="UTF-8" />
<meta name="viewport" content="width=device-width, initial-scale=1.0" />

<title>
    Django Tasks Manager {% block title %} {% endblock title %} | AppSeed
</title>

<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@latest/dist/css/bootstrap.min.css"/>
<link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css"/>

<!-- Specific CSS goes HERE -->
{% block stylesheets %}{% endblock stylesheets %}

</head>
  <body>

    {% block content %} {% endblock content %}

  </body>

  <script src="https://cdn.jsdelivr.net/npm/bootstrap@latest/dist/js/bootstrap.bundle.min.js"></script>

  <!-- Specific JS goes HERE --> 
  {% block javascripts %}{% endblock javascripts %}  
  
</html>
