# -*- encoding: utf-8 -*-
"""
Copyright (c) 2019 - present AppSeed.us
"""

from django.apps import AppConfig

class TasksConfig(AppConfig):

    """
    See https://docs.djangoproject.com/en/2.1/ref/applications/#django.apps.AppConfig
    """

    name = "django_tm"
    label = "django_tm"
    verbose_name = "Django Tasks Manager"

    def ready(self):
        from . import signals
